@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-"HTML Renderer for FPDF.py"
+"""HTML Renderer for FPDF.py"""
 
 __author__ = "Mariano Reingart <reingart@gmail.com>"
 __copyright__ = "Copyright (C) 2010 Mariano Reingart"
@@ -15,7 +13,7 @@ DEBUG = False
 
 
 def px2mm(px):
-    return int(px) * 25.4 / 72.0
+    return int(px) * 25.4 / 72
 
 
 def hex2dec(color="#000000"):
@@ -28,13 +26,14 @@ def hex2dec(color="#000000"):
 
 
 class HTML2FPDF(HTMLParser):
-    "Render basic HTML to FPDF"
+    """Render basic HTML to FPDF"""
 
     def __init__(self, pdf, image_map=None, table_line_separators=False):
         """
         Args:
             pdf (FPDF): an instance of `fpdf.FPDF`
-            image_map (function): an optional one-argument function that map <img> "src" to new image URLs
+            image_map (function): an optional one-argument function that map <img> "src"
+                to new image URLs
             table_line_separators (bool): enable horizontal line separators in <table>
         """
         super().__init__()
@@ -49,7 +48,6 @@ class HTML2FPDF(HTMLParser):
         self.indent = 0
         self.bullet = []
         self.font_size = pdf.font_size_pt
-        self.font_face = "times"  # initialize font face
         self.set_font("times", self.font_size)
         self.font_color = 0, 0, 0  # initialize font color, r,g,b format
         self.table = None  # table attributes
@@ -70,9 +68,9 @@ class HTML2FPDF(HTMLParser):
         if length[-1] == "%":
             total = self.pdf.w - self.pdf.r_margin - self.pdf.l_margin
             if self.table["width"][-1] == "%":
-                total *= int(self.table["width"][:-1]) / 100.0
-            return int(length[:-1]) * total / 101.0
-        return int(length) / 6.0
+                total *= int(self.table["width"][:-1]) / 100
+            return int(length[:-1]) * total / 101
+        return int(length) / 6
 
     def handle_data(self, data):
         if self.td is not None:  # drawing a table?
@@ -82,7 +80,8 @@ class HTML2FPDF(HTMLParser):
                     l = [self.table_col_width[self.table_col_index]]
                 except IndexError:
                     raise ValueError(
-                        "Table column/cell width not specified, unable to continue"
+                        f"Width not specified for table column {self.table_col_index},"
+                        " unable to continue"
                     )
             elif "colspan" in self.td:
                 i = self.table_col_index
@@ -90,7 +89,7 @@ class HTML2FPDF(HTMLParser):
                 l = self.table_col_width[i : i + colspan]
             else:
                 l = [self.td.get("width", "240")]
-            w = sum([self.width2mm(length) for length in l])
+            w = sum(self.width2mm(length) for length in l)
             h = int(self.td.get("height", 0)) // 4 or self.h * 1.30
             self.table_h = h
             border = int(self.table.get("border", 0))
@@ -119,14 +118,22 @@ class HTML2FPDF(HTMLParser):
                 self.box_shadow(w, h, bgcolor)
                 if DEBUG:
                     print("td cell", self.pdf.x, w, data, "*")
-                self.pdf.cell(w, h, data, border, 0, align)
+                self.pdf.cell(w, h, data, border=border, ln=0, align=align)
         elif self.table is not None:
             # ignore anything else than td inside a table
             pass
         elif self.align:
             if DEBUG:
                 print("cell", data, "*")
-            self.pdf.cell(0, self.h, data, 0, 1, self.align[0].upper(), self.href)
+            self.pdf.cell(
+                0,
+                self.h,
+                data,
+                border=0,
+                ln=1,
+                align=self.align[0].upper(),
+                link=self.href,
+            )
         else:
             data = data.replace("\n", " ")
             if self.href:
@@ -175,7 +182,7 @@ class HTML2FPDF(HTMLParser):
     def output_table_sep(self):
         x1 = self.pdf.x
         y1 = self.pdf.y
-        width = sum([self.width2mm(length) for length in self.table_col_width])
+        width = sum(self.width2mm(length) for length in self.table_col_width)
         self.pdf.line(x1, y1, x1 + width, y1)
 
     def handle_starttag(self, tag, attrs):
@@ -191,8 +198,7 @@ class HTML2FPDF(HTMLParser):
         if tag == "p":
             self.pdf.ln(self.h)
             if attrs:
-                if attrs:
-                    self.align = attrs.get("align")
+                self.align = attrs.get("align")
         if tag in self.hsize:
             k = self.hsize[tag]
             self.pdf.ln(5 * k)
@@ -222,8 +228,8 @@ class HTML2FPDF(HTMLParser):
             if not isinstance(bullet, str):
                 bullet += 1
                 self.bullet[self.indent - 1] = bullet
-                bullet = "%s. " % bullet
-            self.pdf.write(self.h, "%s%s " % (" " * 5 * self.indent, bullet))
+                bullet = f"{bullet}. "
+            self.pdf.write(self.h, f"{' ' * 5 * self.indent}{bullet} ")
             self.set_text_color()
         if tag == "font":
             # save previous font state:
@@ -248,8 +254,8 @@ class HTML2FPDF(HTMLParser):
                 self.table["width"] = "100%"
             if self.table["width"][-1] == "%":
                 w = self.pdf.w - self.pdf.r_margin - self.pdf.l_margin
-                w *= int(self.table["width"][:-1]) / 100.0
-                self.table_offset = (self.pdf.w - w) / 2.0
+                w *= int(self.table["width"][:-1]) / 100
+                self.table_offset = (self.pdf.w - w) / 2
             self.table_col_width = []
             self.theader_out = self.tfooter_out = False
             self.theader = []
@@ -277,19 +283,18 @@ class HTML2FPDF(HTMLParser):
             self.thead = {}
         if tag == "tfoot":
             self.tfoot = {}
-        if tag == "img":
-            if "src" in attrs:
-                w = px2mm(attrs.get("width", 0))
-                h = px2mm(attrs.get("height", 0))
-                if self.pdf.y + h > self.pdf.page_break_trigger:
-                    self.pdf.add_page(same=True)
-                x = self.pdf.get_x()
-                y = self.pdf.get_y()
-                if self.align and self.align[0].upper() == "C":
-                    x = self.pdf.w / 2.0 - w / 2.0
-                self.pdf.image(self.image_map(attrs["src"]), x, y, w, h, link=self.href)
-                self.pdf.set_x(x + w)
-                self.pdf.set_y(y + h)
+        if tag == "img" and "src" in attrs:
+            w = px2mm(attrs.get("width", 0))
+            h = px2mm(attrs.get("height", 0))
+            if self.pdf.y + h > self.pdf.page_break_trigger:
+                self.pdf.add_page(same=True)
+            x = self.pdf.get_x()
+            y = self.pdf.get_y()
+            if self.align and self.align[0].upper() == "C":
+                x = self.pdf.w / 2 - w / 2
+            self.pdf.image(self.image_map(attrs["src"]), x, y, w, h, link=self.href)
+            self.pdf.set_x(x + w)
+            self.pdf.set_y(y + h)
         if tag in ("b", "i", "u"):
             self.set_style(tag, True)
         if tag == "center":
@@ -370,13 +375,10 @@ class HTML2FPDF(HTMLParser):
             self.font_face = face
         if size:
             self.font_size = size
-            self.h = size / 72.0 * 25.4
+            self.h = size / 72 * 25.4
             if DEBUG:
                 print("H", self.h)
-        style = ""
-        for s in ("b", "i", "u"):
-            if self.style.get(s):
-                style += s
+        style = "".join(s for s in ("b", "i", "u") if self.style.get(s))
         self.pdf.set_font(self.font_face or "times", style, self.font_size or 12)
         self.pdf.set_font_size(self.font_size or 12)
 
@@ -384,13 +386,10 @@ class HTML2FPDF(HTMLParser):
         # Modify style and select corresponding font
         if tag:
             self.style[tag.lower()] = enable
-        style = ""
-        for s in ("b", "i", "u"):
-            if self.style.get(s):
-                style += s
+        style = "".join(s for s in ("b", "i", "u") if self.style.get(s))
         if DEBUG:
             print("SET_FONT_STYLE", style)
-        self.pdf.set_font("", style)
+        self.pdf.set_font(style=style)
 
     def set_text_color(self, r=None, g=0, b=0):
         if r is None:
@@ -413,7 +412,7 @@ class HTML2FPDF(HTMLParser):
 
 class HTMLMixin:
     def write_html(self, text, *args, **kwargs):
-        "Parse HTML and convert it to PDF"
+        """Parse HTML and convert it to PDF"""
         h2p = HTML2FPDF(self, *args, **kwargs)
         text = html.unescape(text)  # To deal with HTML entities
         h2p.feed(text)
