@@ -1,10 +1,8 @@
-# -*- coding: latin-1 -*-
-
 """PDF Syntax Helpers
 
 Functions in this module take variable input and produce PDF Syntax features
-as they are described in the Adobe PDF Reference Manual, found
-[here](http://www.adobe.com/content/dam/Adobe/en/devnet/acrobat/pdfs/pdf_reference_1-7.pdf).
+as they are described in the Adobe PDF Reference Manual, found here:
+http://www.adobe.com/content/dam/Adobe/en/devnet/acrobat/pdfs/pdf_reference_1-7.pdf
 
 Most of what happens in a PDF happens in objects, which are formatted like so:
 <pre>
@@ -48,10 +46,6 @@ third_obj = {
   pdf_name('Contents'): iobj_ref(4),
 }
 
-`collections.OrderedDict` is used because ultimately to test the accuracy of
-the documents created, order of the fields matters even though it probably
-doesn't in the Adobe Specification.
-
 Some additional notes:
 
 Streams are of the form:
@@ -71,28 +65,32 @@ that string.
 
 As of this writing, I am not sure how length is actually calculated, so this
 remains something to be looked into.
-
 """
-import sys
-from collections import OrderedDict as o_d
 
-py3k = sys.version_info >= (3, 0)
 
 def create_name(name):
-    if name.startswith('/'):
+    if name.startswith("/"):
         name = name[1:]
-    return ''.join(['/', name[0].upper(), name[1:]])
+    return "".join(["/", name[0].upper(), name[1:]])
+
 
 def clear_empty_fields(d):
-    return o_d((k, v) for k, v in d.items() if v)
+    return {k: v for k, v in d.items() if v}
 
-def create_dictionary_string(dict_, open_dict='<<', close_dict='>>',
-    field_join='\n', key_value_join=' ', has_empty_fields=False):
-    """format ordered dictionary as PDF dictionary
+
+def create_dictionary_string(
+    dict_,
+    open_dict="<<",
+    close_dict=">>",
+    field_join="\n",
+    key_value_join=" ",
+    has_empty_fields=False,
+):
+    """format dictionary as PDF dictionary
 
     @param dict_: dictionary of values to render
-    @param open: string to open PDF dictionary
-    @param close: string to close PDF dictionary
+    @param open_dict: string to open PDF dictionary
+    @param close_dict: string to close PDF dictionary
     @param field_join: string to join fields with
     @param key_value_join: string to join key to value with
     @param has_empty_fields: whether or not to clear_empty_fields first.
@@ -100,26 +98,32 @@ def create_dictionary_string(dict_, open_dict='<<', close_dict='>>',
     if has_empty_fields:
         dict_ = clear_empty_fields(dict_)
 
-    return ''.join([
-        open_dict,
-        field_join.join([key_value_join.join(f) for f in dict_.items()]),
-        close_dict
-    ])
+    return "".join(
+        [
+            open_dict,
+            field_join.join([key_value_join.join(f) for f in dict_.items()]),
+            close_dict,
+        ]
+    )
+
 
 def create_list_string(list_):
     """format list of strings as PDF array"""
-    return '[' + ' '.join(list_) + ']'
+    return f"[{' '.join(list_)}]"
+
 
 def iobj_ref(n):
     """format an indirect PDF Object reference from its id number"""
-    return str(n) + ' 0 R'
+    return f"{n} 0 R"
+
 
 def create_stream(stream):
-    if py3k and type(stream) in (bytearray, bytes):
-        stream = str(stream, 'latin-1')
-    return '\n'.join(['stream', stream, 'endstream'])
+    if isinstance(stream, (bytearray, bytes)):
+        stream = str(stream, "latin-1")
+    return "\n".join(["stream", stream, "endstream"])
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     print(create_name("/ok"))
     print(create_name("ok"))
     print(create_name("Ok"))
